==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/komprimierung_tag.sql <==
set @@character_set_client = 'utf8';

delimiter //

DROP PROCEDURE IF EXISTS komprimierung_tag//
create procedure komprimierung_tag()
  deterministic
  sql security invoker
begin
  declare nflag bool;
  declare lwid, wid, uid, z integer;
  declare lw varchar(50);
  declare unit, outunit varchar(100);
  declare mw varchar(20000);
  declare pr, mode varchar(12);
  declare mdate, mkd date;
  declare selcur cursor for
    select lwerteindizes.ID, werteindizes.ID, groupfunctions.code, period,
      lkdate, least(date(lastdatum), curdate()), unitID, einheiten.name,
      type = 'num' OR groupfunctions.code in ('count','differ','firstsize','lastsize')
    from lwerteindizes
    join werteindizes using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
    join letztewerte on letztewerte.ID = werteindizes.ID
    join teststepdetails on teststepdetails.ID = teststepdetailsID
    join einheiten on einheiten.ID = einheitID
    join groupfunctions on groupfunctions.ID = groupfunctionsID
    left join komprimierungids on komprimierungids.lwerteindizesID = lwerteindizes.ID
    where lastdatum - interval 2 day >= lkdate and period in ('Hour', 'Day')
      and (lwerteindizes.single = '1' OR komprimierungids.lwerteindizesID is not NULL)
    group by lwerteindizes.ID
    order by wtab, werteindizes.ID;
  declare continue handler for not found set z = 1;

  set z = 0;
  open selcur;
  fetch selcur into lwid, wid, mode, pr, mdate, mkd, uid, unit, nflag;
  while z = 0 do
    if mdate = '0000-00-00' then
      set mdate = (select min(fdate) from wertedates where werteindizesID = wid);
    else
      set mdate = mdate + interval 1 day;
    end if;
    if mdate < mkd then
      if nflag then
        if unit = '[E]' AND mode not in ('count','differ','firstsize','lastsize') then
          if uid is NULL then
            select lu.unitID
              from lwerteindizes as lr
              join lwerteindizes as lu using (serverID, sectionID, teststepID, teststepdetailsID, accessID)
              where lr.ID = lwid and lu.unitID is not NULL limit 1 into uid;
            if uid is NULL then
              select e.ID, e.name
                from einheiten as e, twerte as w
                where w.werteindizesID = wid
                  and substr(w.wert, instr(w.wert, ' ')+1) = e.name
                group by e.ID order by count(*) desc, e.sifaktor desc limit 1
                into uid, outunit;
            else
              select name from einheiten where ID = uid into outunit;
            end if;
            if uid is NULL then
              set mdate = mkd;
            else
              update lwerteindizes set unitID = uid where ID = lwid;
            end if;
          else
            select name from einheiten where ID = uid into outunit;
          end if;
          while mdate < mkd do
            if pr = 'Hour' then
              if mode like 'last-first%' OR mode = 'grad' then
                insert into mwerte (lwerteindizesID, wert, datum)
                  select lwid, w, t
                    from (select getewertvbextfilteru(wid,
                              getlastwdate(wid, v - interval 1 hour, v), b, mode,
                              '00:00:00', '23:59:59', '', '', '', '', '', '',
                              '', '', '', '', '', '', outunit) as w, t
                          from (select concat(mdate, ' ', v) as v,
                                concat(mdate, ' ', b) as b, concat(mdate, ' ', t) as t
                                from v24h
                               ) as d
                         ) as wt
                  where coalesce(w, '') != ''
                  order by t;
              else
                insert into mwerte (lwerteindizesID, wert, datum)
                  select lwid, w, t
                    from (select getewertvbextfilteru(wid, v, b, mode,
                            '00:00:00', '23:59:59', '',
                            '', '', '', '', '',  '', '', '', '', '', '', outunit) as w, t
                          from (select concat(mdate, ' ', v) as v,
                                concat(mdate, ' ', b) as b, concat(mdate, ' ', t) as t
                                from v24h
                               ) as d
                         ) as wt
                  where coalesce(w, '') != ''
                  order by t;
              end if;
              if row_count() > 0 then
                call lwdates(lwid, mdate);
              end if;
            else
              if mode like 'last-first%' OR mode = 'grad' then
                set mw =  getewertvbextfilteru(wid,
                            getlastwdate(wid, mdate - interval 1 day, mdate),
                            concat(mdate, ' 23:59:59'), mode, '00:00:00', '23:59:59',
                            '', '', '', '', '', '',  '', '', '', '', '', '', outunit);
              else
                set mw =  getewertvbextfilteru(wid, mdate, concat(mdate, ' 23:59:59'), mode,
                            '00:00:00', '23:59:59', '', '', '',
                            '', '', '',  '', '', '', '', '', '', outunit);
              end if;
              if coalesce(mw, '') != '' then
                insert into mwerte (lwerteindizesID, wert, datum) values
                  (lwid, mw, concat(mdate, ' 12:00:00'));
                call lwdates(lwid, mdate);
              end if;
            end if;
            update lwerteindizes set lkdate = mdate where ID = lwid;
            set mdate = mdate + interval 1 day;
          end while;
        else
          while mdate < mkd do
            if pr = 'Hour' then
              if mode like 'last-first%' OR mode = 'grad' then
                insert into lwerte (lwerteindizesID, wert, datum)
                  select lwid, w, t
                    from (select getwertvb(wid,getlastwdate(wid, v - interval 1 hour, v),
                                           b, mode) as w, t
                          from (select concat(mdate, ' ', v) as v,
                                concat(mdate, ' ', b) as b, concat(mdate, ' ', t) as t
                                from v24h
                               ) as d
                         ) as wt
                  where coalesce(w, '') != ''
                  order by t;
              else
                insert into lwerte (lwerteindizesID, wert, datum)
                  select lwid, w, t
                    from (select getwertvb(wid, v, b, mode) as w, t
                          from (select concat(mdate, ' ', v) as v,
                                concat(mdate, ' ', b) as b, concat(mdate, ' ', t) as t
                                from v24h
                               ) as d
                         ) as wt
                  where coalesce(w, '') != ''
                  order by t;
              end if;
              if row_count() > 0 then
                call lwdates(lwid, mdate);
              end if;
            else
              if mode like 'last-first%' OR mode = 'grad' then
                set lw =  getwertvb(wid, getlastwdate(wid, mdate - interval 1 day, mdate),
                                    concat(mdate, ' 23:59:59'), mode);
              else
                set lw =  getwertvb(wid, mdate, concat(mdate, ' 23:59:59'), mode);
              end if;
              if coalesce(lw, '') != '' then
                insert into lwerte (lwerteindizesID, wert, datum) values
                  (lwid, lw, concat(mdate, ' 12:00:00'));
                call lwdates(lwid, mdate);
              end if;
            end if;
            update lwerteindizes set lkdate = mdate where ID = lwid;
            set mdate = mdate + interval 1 day;
          end while;
        end if;
      else
        while mdate < mkd do
          if pr = 'Hour' then
            if mode like 'last-first%' OR mode = 'grad' then
              insert into mwerte (lwerteindizesID, wert, datum)
                select lwid, w, t
                  from (select getwertvb(wid,getlastwdate(wid, v - interval 1 hour, v),
                                         b, mode) as w, t
                        from (select concat(mdate, ' ', v) as v,
                              concat(mdate, ' ', b) as b, concat(mdate, ' ', t) as t
                              from v24h
                             ) as d
                       ) as wt
                where coalesce(w, '') != ''
                order by t;
            else
              insert into mwerte (lwerteindizesID, wert, datum)
                select lwid, w, t
                  from (select getwertvb(wid, v, b, mode) as w, t
                        from (select concat(mdate, ' ', v) as v,
                              concat(mdate, ' ', b) as b, concat(mdate, ' ', t) as t
                              from v24h
                             ) as d
                       ) as wt
                where coalesce(w, '') != ''
                order by t;
            end if;
            if row_count() > 0 then
              call lwdates(lwid, mdate);
            end if;
          else
            if mode like 'last-first%' OR mode = 'grad' then
              set mw =  getwertvb(wid, getlastwdate(wid, mdate - interval 1 day, mdate),
                                  concat(mdate, ' 23:59:59'), mode);
            else
              set mw =  getwertvb(wid, mdate, concat(mdate, ' 23:59:59'), mode);
            end if;
            if coalesce(mw, '') != '' then
              insert into mwerte (lwerteindizesID, wert, datum) values
                (lwid, mw, concat(mdate, ' 12:00:00'));
              call lwdates(lwid, mdate);
            end if;
          end if;
          update lwerteindizes set lkdate = mdate where ID = lwid;
          set mdate = mdate + interval 1 day;
        end while;
      end if;
    end if;
    fetch selcur into lwid, wid, mode, pr, mdate, mkd, uid, unit, nflag;
  end while;
  close selcur;

end//

GRANT EXECUTE on PROCEDURE komprimierung_tag to loggingadmin@'localhost'//

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/komprimierung_tag.sql <==
-- komprimierung_tag.sql
--
-- procedure komprimierung_tag()
-- 
-- calculate and insert compressed values for on day and the 24 hours
--
-- komprimiert wird bis zum Vortag der letzten Werte, aber mindestens bis vorgestern

set @@character_set_client = 'utf8';

delimiter //

DROP PROCEDURE IF EXISTS komprimierung_tag//
create procedure komprimierung_tag()
  deterministic
  sql security invoker
begin
  declare nflag bool;
  declare lwid, wid, uid, z integer;
  declare lw varchar(50);
  declare unit, outunit varchar(100);
  declare mw varchar(20000);
  declare pr, mode varchar(12);
  declare mdate, mkd date;
  declare selcur cursor for
    select lwerteindizes.ID, werteindizes.ID, groupfunctions.code, period,
      lkdate, greatest(least(date(lastdatum), curdate()), curdate() - interval 1 day), unitID, einheiten.name,
      type = 'num' OR groupfunctions.code in ('count','differ','firstsize','lastsize')
    from lwerteindizes
    join werteindizes using(serverID, sectionID, teststepID, teststepdetailsID, accessID)
    join letztewerte on letztewerte.ID = werteindizes.ID
    join teststepdetails on teststepdetails.ID = teststepdetailsID
    join einheiten on einheiten.ID = einheitID
    join groupfunctions on groupfunctions.ID = groupfunctionsID
    left join komprimierungids on komprimierungids.lwerteindizesID = lwerteindizes.ID
    where lastdatum - interval 2 day >= lkdate and period in ('Hour', 'Day')
      and (lwerteindizes.single = '1' OR komprimierungids.lwerteindizesID is not NULL)
    group by lwerteindizes.ID
    order by wtab, werteindizes.ID;
  declare continue handler for not found set z = 1;

  set z = 0;
  open selcur;
  fetch selcur into lwid, wid, mode, pr, mdate, mkd, uid, unit, nflag;
  while z = 0 do
    if mdate = '0000-00-00' then
      set mdate = (select min(fdate) from wertedates where werteindizesID = wid);
    else
      set mdate = mdate + interval 1 day;
    end if;
    if mdate < mkd then
      if nflag then
        if unit = '[E]' AND mode not in ('count','differ','firstsize','lastsize') then
          if uid is NULL then
            select lu.unitID into uid
              from lwerteindizes as lr
              join lwerteindizes as lu using (serverID, sectionID, teststepID, teststepdetailsID, accessID)
              where lr.ID = lwid and lu.unitID is not NULL limit 1;
            if uid is NULL then
              select e.ID, e.name into uid, outunit
                from einheiten as e, twerte as w
                where w.werteindizesID = wid
                  and substr(w.wert, instr(w.wert, ' ')+1) = e.name
                group by e.ID order by count(*) desc, e.sifaktor desc limit 1;
            else
              select name into outunit from einheiten where ID = uid;
            end if;
            if uid is NULL then
              set mdate = mkd;
            else
              update lwerteindizes set unitID = uid where ID = lwid;
            end if;
          else
            select name into outunit from einheiten where ID = uid;
          end if;
          while mdate < mkd do
            if pr = 'Hour' then
              if mode like 'last-first%' OR mode = 'grad' then
                insert into mwerte (lwerteindizesID, wert, datum)
                  select lwid, w, t
                    from (select getewertvbextfilteru(wid,
                              getlastwdate(wid, v - interval 1 hour, v), b, mode,
                              '00:00:00', '23:59:59', '', '', '', '', '', '',
                              '', '', '', '', '', '', outunit) as w, t
                          from (select concat(mdate, ' ', v) as v,
                                concat(mdate, ' ', b) as b, concat(mdate, ' ', t) as t
                                from v24h
                               ) as d
                         ) as wt
                  where coalesce(w, '') != ''
                  order by t;
              else
                insert into mwerte (lwerteindizesID, wert, datum)
                  select lwid, w, t
                    from (select getewertvbextfilteru(wid, v, b, mode,
                            '00:00:00', '23:59:59', '',
                            '', '', '', '', '',  '', '', '', '', '', '', outunit) as w, t
                          from (select concat(mdate, ' ', v) as v,
                                concat(mdate, ' ', b) as b, concat(mdate, ' ', t) as t
                                from v24h
                               ) as d
                         ) as wt
                  where coalesce(w, '') != ''
                  order by t;
              end if;
              if row_count() > 0 then
                call lwdates(lwid, mdate);
              end if;
            else
              if mode like 'last-first%' OR mode = 'grad' then
                set mw =  getewertvbextfilteru(wid,
                            getlastwdate(wid, mdate - interval 1 day, mdate),
                            concat(mdate, ' 23:59:59'), mode, '00:00:00', '23:59:59',
                            '', '', '', '', '', '',  '', '', '', '', '', '', outunit);
              else
                set mw =  getewertvbextfilteru(wid, mdate, concat(mdate, ' 23:59:59'), mode,
                            '00:00:00', '23:59:59', '', '', '',
                            '', '', '',  '', '', '', '', '', '', outunit);
              end if;
              if coalesce(mw, '') != '' then
                insert into mwerte (lwerteindizesID, wert, datum) values
                  (lwid, mw, concat(mdate, ' 12:00:00'));
                call lwdates(lwid, mdate);
              end if;
            end if;
            update lwerteindizes set lkdate = mdate where ID = lwid;
            set mdate = mdate + interval 1 day;
          end while;
        else
          while mdate < mkd do
            if pr = 'Hour' then
              if mode like 'last-first%' OR mode = 'grad' then
                insert into lwerte (lwerteindizesID, wert, datum)
                  select lwid, w, t
                    from (select getwertvb(wid,getlastwdate(wid, v - interval 1 hour, v),
                                           b, mode) as w, t
                          from (select concat(mdate, ' ', v) as v,
                                concat(mdate, ' ', b) as b, concat(mdate, ' ', t) as t
                                from v24h
                               ) as d
                         ) as wt
                  where coalesce(w, '') != ''
                  order by t;
              else
                insert into lwerte (lwerteindizesID, wert, datum)
                  select lwid, w, t
                    from (select getwertvb(wid, v, b, mode) as w, t
                          from (select concat(mdate, ' ', v) as v,
                                concat(mdate, ' ', b) as b, concat(mdate, ' ', t) as t
                                from v24h
                               ) as d
                         ) as wt
                  where coalesce(w, '') != ''
                  order by t;
              end if;
              if row_count() > 0 then
                call lwdates(lwid, mdate);
              end if;
            else
              if mode like 'last-first%' OR mode = 'grad' then
                set lw =  getwertvb(wid, getlastwdate(wid, mdate - interval 1 day, mdate),
                                    concat(mdate, ' 23:59:59'), mode);
              else
                set lw =  getwertvb(wid, mdate, concat(mdate, ' 23:59:59'), mode);
              end if;
              if coalesce(lw, '') != '' then
                insert into lwerte (lwerteindizesID, wert, datum) values
                  (lwid, lw, concat(mdate, ' 12:00:00'));
                call lwdates(lwid, mdate);
              end if;
            end if;
            update lwerteindizes set lkdate = mdate where ID = lwid;
            set mdate = mdate + interval 1 day;
          end while;
        end if;
      else
        while mdate < mkd do
          if pr = 'Hour' then
            if mode like 'last-first%' OR mode = 'grad' then
              insert into mwerte (lwerteindizesID, wert, datum)
                select lwid, w, t
                  from (select getwertvb(wid,getlastwdate(wid, v - interval 1 hour, v),
                                         b, mode) as w, t
                        from (select concat(mdate, ' ', v) as v,
                              concat(mdate, ' ', b) as b, concat(mdate, ' ', t) as t
                              from v24h
                             ) as d
                       ) as wt
                where coalesce(w, '') != ''
                order by t;
            else
              insert into mwerte (lwerteindizesID, wert, datum)
                select lwid, w, t
                  from (select getwertvb(wid, v, b, mode) as w, t
                        from (select concat(mdate, ' ', v) as v,
                              concat(mdate, ' ', b) as b, concat(mdate, ' ', t) as t
                              from v24h
                             ) as d
                       ) as wt
                where coalesce(w, '') != ''
                order by t;
            end if;
            if row_count() > 0 then
              call lwdates(lwid, mdate);
            end if;
          else
            if mode like 'last-first%' OR mode = 'grad' then
              set mw =  getwertvb(wid, getlastwdate(wid, mdate - interval 1 day, mdate),
                                  concat(mdate, ' 23:59:59'), mode);
            else
              set mw =  getwertvb(wid, mdate, concat(mdate, ' 23:59:59'), mode);
            end if;
            if coalesce(mw, '') != '' then
              insert into mwerte (lwerteindizesID, wert, datum) values
                (lwid, mw, concat(mdate, ' 12:00:00'));
              call lwdates(lwid, mdate);
            end if;
          end if;
          update lwerteindizes set lkdate = mdate where ID = lwid;
          set mdate = mdate + interval 1 day;
        end while;
      end if;
    end if;
    fetch selcur into lwid, wid, mode, pr, mdate, mkd, uid, unit, nflag;
  end while;
  close selcur;

end//

GRANT EXECUTE on PROCEDURE komprimierung_tag to loggingadmin@'localhost'//
